@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 import argparse
-from sarscov2_meta_extract import convertor
+from sarscov2metaextract import convertor
 
 def main()
 	parser = argparse.ArgumentParser(description='Metadata extractor for SARS-CoV-2 selection analysis pipeline in Galaxy')
